@@ -4,10 +4,18 @@
 #'
 #' @export
 #' @param x (character) vector of scientific names. required
-#' @param threads (integer/numeric) number of threads to run. CPU's
-#' threads number is the default. default: `4`
+#' @param threads (integer/numeric) number of threads to run for parallel
+#'   processing. Setting to `NULL` will use all threads available. default: `1`
 #' @param batch_size (integer/numeric) maximum number of names in a
 #' batch send for processing. default: `NULL`
+#' @param cultivar (logical) adds support for botanical cultivars like
+#'   `Sarracenia flava 'Maxima'` and graft-chimaeras like `+ Crataegomespilus`.
+#'   default: `FALSE`
+#' @param capitalize (logical) capitalizes the first letter of name-strings.
+#'   default: `FALSE`
+#' @param diaereses (logical) preserves diaereses within names, e.g.
+#'   `Leptochloöpsis virgata`. The stemmed canonical name will be generated
+#'   without diaereses. default: `FALSE`
 #' @param ignore_tags (logical) ignore HTML entities and tags when
 #' parsing. default: `FALSE`
 #' @param details (logical) Return more details for a parsed name
@@ -28,8 +36,15 @@
 #' z <- trys(gn_parse(x, details = FALSE)) # compared to regular
 #' z
 #' }
-gn_parse <- function(x, threads = NULL, batch_size = NULL,
-  ignore_tags = FALSE, details = FALSE) {
+gn_parse <- function(
+  x,
+  threads = 1,
+  batch_size = NULL,
+  ignore_tags = FALSE,
+  cultivar = FALSE,
+  capitalize = FALSE,
+  diaereses = FALSE,
+  details = FALSE) {
 
   gnparser_exists()
   ver_check(1)
@@ -38,6 +53,6 @@ gn_parse <- function(x, threads = NULL, batch_size = NULL,
   on.exit(unlink(file))
   cat(x, file = file, sep = "\n")
   res <- parse_one(file, "compact", threads, batch_size,
-    ignore_tags, details)
+    ignore_tags, cultivar, capitalize, diaereses, details)
   lapply(strsplit(res, "\n")[[1]], jsonlite::fromJSON)
 }
